API Documentation
=================

Tools
-----

Preprocessing
~~~~~~~~~~~~~

.. automodule:: singlecell_cookbook.tools.preprocess
   :members:
   :undoc-members:
   :show-inheritance:

Analysis
~~~~~~~~

.. automodule:: singlecell_cookbook.tools.analysis
   :members:
   :undoc-members:
   :show-inheritance:
